*************
API Reference
*************

.. rubric:: Functions

.. autosummary::
   :toctree: api

   macromol_voxelize.image_from_atoms
   macromol_voxelize.image_from_all_atoms
   macromol_voxelize.discard_atoms_outside_image
   macromol_voxelize.set_atom_radius_A
   macromol_voxelize.set_atom_channels_by_element
   macromol_voxelize.add_atom_channel_by_expr
   macromol_voxelize.get_voxel_center_coords
   macromol_voxelize.find_occupied_voxels

.. rubric:: Data structures

.. autosummary::
   :toctree: api

   macromol_voxelize.Image
   macromol_voxelize.ImageParams
   macromol_voxelize.Grid
   macromol_voxelize.FillAlgorithm
   macromol_voxelize.AggAlgorithm

.. rubric:: Exceptions

.. autosummary::
   :toctree: api

   macromol_voxelize.ValidationError
